@@ -35,6 +35,7 @@
 G_DEFINE_TYPE (EEwsFolder, e_ews_folder, G_TYPE_OBJECT)
 
 struct _EEwsFolderPrivate {
+	GError *error;
 	gchar *name;
 	EwsFolderId *fid;
 	EwsFolderId *parent_fid;
@@ -69,6 +70,8 @@ e_ews_folder_finalize (GObject *object)
 
 	priv = folder->priv;
 
+	g_clear_error (&priv->error);
+
 	if (priv->name) {
 		g_free (priv->name);
 		priv->name = NULL;
@@ -115,7 +118,8 @@ e_ews_folder_init (EEwsFolder *folder)
 	priv = g_new0 (EEwsFolderPrivate, 1);
 	folder->priv = priv;
 
-	priv->folder_type = E_EWS_FOLDER_TYPE_MAILBOX;
+	priv->error = NULL;
+	priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
 	priv->foreign = FALSE;
 }
 
@@ -177,6 +181,12 @@ e_ews_folder_set_from_soap_parameter (EEwsFolder *folder,
 	if (subparam) {
 		value = e_soap_parameter_get_string_value (subparam);
 		e_ews_folder_set_folder_class (folder, (const gchar *) value);
+
+		if (value && priv->folder_type == E_EWS_FOLDER_TYPE_MAILBOX &&
+		    g_strcmp0 (value, "IPF.Note") != 0 && !g_str_has_prefix (value, "IPF.Note.")) {
+			priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
+		}
+
 		g_free (value);
 	}
 
@@ -263,6 +273,35 @@ e_ews_folder_new_from_soap_parameter (ESoapParameter *param)
 	return folder;
 }
 
+EEwsFolder *
+e_ews_folder_new_from_error (const GError *error)
+{
+	EEwsFolder *folder;
+
+	g_return_val_if_fail (error != NULL, NULL);
+
+	folder = g_object_new (E_TYPE_EWS_FOLDER, NULL);
+	folder->priv->error = g_error_copy (error);
+
+	return folder;
+}
+
+gboolean
+e_ews_folder_is_error (EEwsFolder *folder)
+{
+	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), TRUE);
+
+	return folder->priv->error != NULL;
+}
+
+const GError *
+e_ews_folder_get_error (EEwsFolder *folder)
+{
+	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), NULL);
+
+	return folder->priv->error;
+}
+
 EwsFolderId *
 e_ews_folder_id_new (const gchar *id,
                      const gchar *change_key,
@@ -511,7 +550,7 @@ e_ews_folder_utils_populate_esource (ESource *source,
 			ESourceEwsFolder *folder_ext;
 			ESourceOffline *offline_ext;
 
-			e_source_backend_set_backend_name (backend_ext , "ews");
+			e_source_backend_set_backend_name (backend_ext, "ews");
 
 			folder_ext = e_source_get_extension (source, E_SOURCE_EXTENSION_EWS_FOLDER);
 			e_source_ews_folder_set_id (folder_ext, folder_id->id);
@@ -523,6 +562,7 @@ e_ews_folder_utils_populate_esource (ESource *source,
 
 			/* set also color for calendar-like sources */
 			if (folder_type != E_EWS_FOLDER_TYPE_CONTACTS) {
+				ESourceAlarms *alarms;
 				gchar *color_str;
 
 				color_str = e_ews_folder_utils_pick_color_spec (
@@ -530,6 +570,9 @@ e_ews_folder_utils_populate_esource (ESource *source,
 					folder_type != E_EWS_FOLDER_TYPE_CALENDAR);
 				e_source_selectable_set_color (E_SOURCE_SELECTABLE (backend_ext), color_str);
 				g_free (color_str);
+
+				alarms = e_source_get_extension (source, E_SOURCE_EXTENSION_ALARMS);
+				e_source_alarms_set_include_me (alarms, FALSE);
 			}
 
 			res = TRUE;
